docs = [
    {
        "path": "../docs/rag",
    },
    {
        "path": "../docs/rag/build/",
    },
    {
        "path": "../docs/rag/build/one.md",
    },
    {
        "path": "../docs/rag/query/",
    },
    {
        "path": "../docs/rag/query/one.md",
    },
]



import argparse
import base64

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_agent import NAME
from bluer_agent.rag.query import query
from bluer_agent.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="query",
)
parser.add_argument(
    "--object_name",
    type=str,
)
parser.add_argument(
    "--encoded_query",
    type=str,
)
parser.add_argument(
    "--top_k",
    type=int,
    default=5,
)
args = parser.parse_args()

success = False
if args.task == "query":
    success, _ = query(
        object_name=args.object_name,
        query=base64.b64decode(args.encoded_query).decode("utf-8"),
        top_k=args.top_k,
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from typing import Tuple

from blueness import module

from bluer_agent import NAME
from bluer_agent.rag.corpus.context import Context
from bluer_agent.rag.prompt import build_prompt
from bluer_agent.chat.functions import chat
from bluer_agent.logger import logger


NAME = module.name(__file__, NAME)


def query(
    object_name: str,
    query: str,
    top_k: int = 5,
) -> Tuple[bool, str]:
    logger.info(f'{NAME}.query[{object_name}]("{query}")')

    context = Context(object_name)

    success, query_context = context.generate(
        query=query,
        top_k=top_k,
    )
    if not success:
        return success, ""

    return chat(
        messages=build_prompt(
            query=query,
            context=query_context["chunks"],
        )
    )
